mod xapcm;

use crate::audio::my_xa::Orality;

use super::Arguments;
use super::raw_audio::{I16Samples, Settings};
use std::io::Write;
use symphonia::core::audio::Layout;
use tool_helper::Error;

const BLOCKS_PER_SECTOR:usize = 18;
const HIGH_FREQUENCY:u32      = 37_800;
const  LOW_FREQUENCY:u32      = 18_900;

pub fn audio_conversion_settings(arguments: &Arguments) -> Settings {
    let frequency = match arguments.frequency {
        super::Frequency::High => HIGH_FREQUENCY,
        super::Frequency::Low  => LOW_FREQUENCY,
    };
    let layout    = match arguments.orality {
        super::Orality::Stereo => Layout::Stereo,
        super::Orality::Mono   => Layout::Mono,
    };

    Settings::new(frequency, layout)
}

pub fn encode(input: I16Samples, output: &mut dyn Write, arguments: &Arguments) -> Result<(), Error> {
    let (samples_per_block, sample_count) = init_values(&input, arguments);

    for (sectors, sampled_id) in (0..sample_count).step_by(samples_per_block).enumerate() {
        let slice = &input[sampled_id..];

        print!("\rIteration: {}; Sample: {}", iteration, sampled_id);
    }
    println!();
    Err(Error::not_implemented("XA conversion"))
}

fn init_values(input: &I16Samples, arguments: &Arguments) -> (usize, usize) {
    let samples_per_block = match arguments.sample_depth {
        super::SampleDepth::Normal => 224,
        super::SampleDepth::High   => 112,
    };

    let sample_count = match arguments.orality {
        super::Orality::Stereo => input.len()/2,
        super::Orality::Mono   => input.len(),
    };

    (samples_per_block as usize, sample_count)
}